2023-03-23 Version: 1.0.15
- Fix some bugs.
- Support PathLenConstraint and ExtendedKeyUsages.

2023-02-13 Version: 1.0.14
- Fix some bugs.

2022-11-29 Version: 1.0.13
- Fix some bugs.

2021-12-23 Version: 0.1.2
- Return the CertificateChain.

2021-11-30 Version: 0.20200630.0
- Publish.

